#!/usr/bin/env python

import click

from public_service import PublicServicePKI
from registration_service import RegistrationService
from domain_service import DomainService
from utils import get_wsdl


@click.command()
@click.version_option()
def main():

    proxy = {"http": "http://proxy.charite.de:8080", "https": "http://proxy.charite.de:8080"}

    pki = PublicServicePKI("../config.ini", proxy=proxy)
    ca_info = pki.get_ca_info(510)

    # print(ca_info)

    with open("PN_Robert_Graetz_-_Charite_Teilnehmerservice_Berlin_2021-01-04.p12", 'rb') as pkcs12_file:
        pkcs12_data = pkcs12_file.read()

        print(pkcs12_data)
        print(type(pkcs12_data))
    pkcs12_password = "5+k,%yyy"
    rs = RegistrationService("../config.ini", proxy, pkcs12_data, pkcs12_password)

    print(rs.get_ca_info())

    result = rs.search_items_2("certificate", "VALID", None, 510, None, 1)
    # print(result)

    ds = DomainService("../config.ini", proxy, pkcs12_data, pkcs12_password)
    result = ds.list_domains(510)
    # print(result)

    # return obj.DFNCERTTypesDomainListResult(res.Change, results, acl)
    domain_list_results = ds.list_extended_domains(510)
    test = domain_list_results.result
    for domain in test:
        print(domain)
        print(type(domain))
        print(domain.name)
        print(domain.type)
        print(domain.secret)
        print(domain.approved)
        print(domain.approved_date)
        print(domain.method)
        print(domain.br_version)
        print(domain.challenge_mail_address)
        print(domain.last_challenge_mail_sent)
        print(domain.valid_until)



if __name__ == '__main__':
    main()



#!/usr/bin/env python

import csv
import datetime
import os
import re
import signal
import sys

import bonsai
import requests


def main():

    response = requests.get("http://argos.charite.de/api/charite-pki/valid_certificates")

    valid_certs = response.json()


    function_email_list = []

    with open("function_emails.csv", "r") as csv_file:
        func_email_reader = csv.reader(csv_file)
        function_email_list = [row[0] for row in func_email_reader]

    base = "cn=Personen,dc=charite.de"

    ldap_user = "uid=adminread,cn=Personen,dc=charite.de"
    ldap_secret = "itzldap"

    i = 0
    client = bonsai.LDAPClient("ldaps://kruemel.charite.de")
    client.set_credentials("SIMPLE", user=ldap_user, password=ldap_secret)

    conn = client.connect()

    for cert in valid_certs:
        email = []
        if "email" in cert and cert["email"]:
            if ", " in cert["email"]:
                email = cert["email"].split(", ")
            else:
                email = [cert["email"]]

        add_email = []
        if "additonal_email" in cert and cert["additonal_email"]:
            if ", " in cert["additonal_email"]:
                add_email = cert["additonal_email"].split(", ")
            else:
                add_email = [cert["additonal_email"]]
        emails = list(set(email + add_email))

        role = cert["role"]
        if role == "802.1.X User":
            # if not any(func_email in emails for func_email in function_email_list):
            for func_mail in function_email_list:
                if func_mail in emails:
                    emails = [e for e in emails if e != func_mail]
            if emails:
                results = [conn.search(base, 2, f"(mail={email_addr})") for email_addr in emails]
                if not [res for res in results if res != []]:
                    # check_other_domain(conn, base, emails)
                    # i = i + 1
                    # print(results)
                    pass

                    # found user with wrong email address

    # print(i)
    conn.close()


def check_other_domain(conn, base: str, emails: list):
    results = [conn.search(base, 2, f"(mail={email_addr[:email_addr.index('@')]}*)") for email_addr in emails]
    if not [res for res in results if res != []]:

        mail = emails[0]
        if '.' not in mail[:mail.index('@')]:
            return None
        cn_normal = mail[:mail.index('@')]
        cn_normal = re.sub(r'[.-_]', '', cn_normal)
        cn_normal_search = conn.search(base, 2, f"(cnNormal={cn_normal})")
        if len(cn_normal_search) > 0 and "DatumExStudenten" in cn_normal_search[0]:
            date_str = list(cn_normal_search[0]["DatumExStudenten"])[0]
            # print(f"date_str: {date_str}")
            try:
                exit_date = datetime.datetime.strptime(date_str, "%Y-%m-%d")
                # print(exit_date)
                if datetime.datetime.now() > exit_date:
                    print(exit_date)
                    print(cn_normal_search)
                    cn = list(cn_normal_search[0].get("cn", "Unbekannt"))[0]
                    print(cn)
            except ValueError as value_err:
                print(value_err)


def find_ey_employee():
    pass


if __name__ == "__main__":
    main()



def get_errors():

    result = {}

    valid_certs = models.ValidCertificates.query.all()

    function_email_list = []

    with open("app/function_emails.csv", "r") as csv_file:
        func_email_reader = csv.reader(csv_file)
        function_email_list = [row[0] for row in func_email_reader]


    base = "cn=Personen,dc=charite.de"

    ldap_user = "uid=adminread,cn=Personen,dc=charite.de"
    ldap_secret = "itzldap"

    client = bonsai.LDAPClient("ldaps://kruemel.charite.de")
    client.set_credentials("SIMPLE", user=ldap_user, password=ldap_secret)

    conn = client.connect()

    for cert in valid_certs:
        if isinstance(cert.email, list):
            emails = cert.email.split(", ")
        else:
            emails = []
        alt_email = cert.additional_email
        role = cert.role

        if emails and role == "8":
            email_addresses = emails.split(", ")
            if not any(func_email in emails for func_email in function_email_list):
                results = [conn.search(base, 2, f"(mail={email_addr})") for email_addr in email_addresses]
                if not [res for res in results if res != []]:
                    result[cert.serial] = cert

    conn.close()

    return result



#!/usr/bin/env python

import base64
import time

import paramiko


def main():

    hostname = "argos.charite.de"
    username = "rgraetz-adm"
    password = "5+k,%yyy"
    cert_password = "5+k,%yyy"
    cert_file_name = "PN_Robert_Graetz_-_Charite_Teilnehmerservice_Berlin_2021-01-04.p12"
    with open(cert_file_name, 'rb') as pkcs12_file:
        pkcs12_data = pkcs12_file.read()

    b = base64.b64encode(pkcs12_data)

    commands = [
        "unset HISTFILE",
        # "source venv/bin/activate",
        # "pip freeze",
        # f"python3 test.py '5+k,%yyy' '{b}'"
        f"bash run_pki.sh '{cert_password}' \"{b}\""
    ]

    # initialize the SSH client
    client = paramiko.SSHClient()
    # add to known hosts
    client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    try:
        client.connect(hostname=hostname, username=username, password=password)
    except:
        print("[!] Cannot connect to the SSH Server")
        exit()

    # execute the commands
    for command in commands:
        print("="*50, command, "="*50)
        # timeout=20
        stdin, stdout, stderr = client.exec_command(command)
        time.sleep(5)
        print(stdout.read().decode())
        err = stderr.read().decode()
        if err:
            print(err)


if __name__ == "__main__":
    main()



#!/usr/bin/env python

import csv
import datetime
import os
import re
import signal
import sys

import bonsai
import requests


def main():
    response = requests.get("http://argos.charite.de/api/charite-pki/valid_certificates")

    valid_certs = response.json()

    for cert in valid_certs:
        emails = []
        if "email" in cert and cert["email"]:
            if ", " in cert["email"]:
                emails = cert["email"].split(", ")
            else:
                emails = [cert["email"]]

        role = cert["role"]
        if role == "802.1.X User":
            for mail in emails:
                if "bihealth.de" in mail and len(emails) < 2:
                    print(emails)
                    print(cert)
                    name = ""
                    if cert['additional_name']:
                        name = cert['additional_name']
                    else:
                        if cert["subject"]:
                            print(cert["subject"])
                            name = re.search(r'CN=([\w+\s-]*),', cert["subject"]).group(1)
                        else:
                            name = "Unbekannt"
                    print(f"Das Zertifikat vom Nutzer {name} besitzt nur einen @bihealt.de-Maileintrag.")





def test():

    response = requests.get("http://argos.charite.de/api/charite-pki/valid_certificates")

    valid_certs = response.json()


    function_email_list = []

    with open("function_emails.csv", "r") as csv_file:
        func_email_reader = csv.reader(csv_file)
        function_email_list = [row[0] for row in func_email_reader]

    base = "cn=Personen,dc=charite.de"

    ldap_user = "uid=adminread,cn=Personen,dc=charite.de"
    ldap_secret = "itzldap"

    i = 0
    client = bonsai.LDAPClient("ldaps://kruemel.charite.de")
    client.set_credentials("SIMPLE", user=ldap_user, password=ldap_secret)

    conn = client.connect()

    for cert in valid_certs:
        email = []
        if "email" in cert and cert["email"]:
            if ", " in cert["email"]:
                email = cert["email"].split(", ")
            else:
                email = [cert["email"]]

        add_email = []
        if "additonal_email" in cert and cert["additonal_email"]:
            if ", " in cert["additonal_email"]:
                add_email = cert["additonal_email"].split(", ")
            else:
                add_email = [cert["additonal_email"]]
        emails = list(set(email + add_email))

        role = cert["role"]
        if role == "802.1.X User":
            # if not any(func_email in emails for func_email in function_email_list):
            for func_mail in function_email_list:
                if func_mail in emails:
                    emails = [e for e in emails if e != func_mail]
            if emails:
                results = [conn.search(base, 2, f"(mail={email_addr[:email_addr.index('@')+1]}*)") for email_addr in emails]
                if [res for res in results if res != []]:
                    pass
                    print(results)

    conn.close()


if __name__ == "__main__":
    main()
